#ifndef NT2_INCLUDE_FUNCTIONS_ASINPI_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_ASINPI_HPP_INCLUDED

#include <nt2/trigonometric/include/functions/asinpi.hpp>

#endif
